@@ -1,4 +1,4 @@
-# Install and start **blazar** reservations service
+# Install and start **blazar** reservation service
 
 # Save trace setting
 XTRACE=$(set +o | grep xtrace)
@@ -21,19 +21,6 @@ function is_blazar_enabled {
     return 1
 }
 
-# Oslo.Messaging RPC iniupdate configuration
-function iniupdate_rpc_backend {
-    local file=$1
-    local section=$2
-    if is_service_enabled zeromq; then
-        iniset $file $section rpc_backend zmq
-    elif is_service_enabled qpid || [ -n "$QPID_HOST" ]; then
-        iniset $file $section rpc_backend qpid
-    elif is_service_enabled rabbit || { [ -n "$RABBIT_HOST" ] && [ -n "$RABBIT_PASSWORD" ]; }; then
-        iniset $file $section rpc_backend rabbit
-    fi
-}
-
 # configure_blazar() - Set config files, create data dirs, etc
 function configure_blazar {
     if [[ ! -d $BLAZAR_CONF_DIR ]]; then
@@ -44,7 +31,7 @@ function configure_blazar {
     touch $BLAZAR_CONF_FILE
 
     iniset $BLAZAR_CONF_FILE DEFAULT os_auth_version v3
-    iniset $BLAZAR_CONF_FILE DEFAULT os_auth_host $KEYSTONE_AUTH_HOST
+    iniset $BLAZAR_CONF_FILE DEFAULT os_auth_host $(ipv6_unquote $KEYSTONE_AUTH_HOST)
     iniset $BLAZAR_CONF_FILE DEFAULT os_auth_port 80
     iniset $BLAZAR_CONF_FILE DEFAULT os_auth_prefix identity
     iniset $BLAZAR_CONF_FILE DEFAULT os_admin_password $SERVICE_PASSWORD
@@ -58,10 +45,10 @@ function configure_blazar {
 
     iniset $BLAZAR_CONF_FILE nova aggregate_freepool_name $BLAZAR_FREEPOOL_NAME
 
-    iniset $BLAZAR_CONF_FILE DEFAULT host $HOST_IP
+    iniset $BLAZAR_CONF_FILE DEFAULT host $(ipv6_unquote $SERVICE_HOST)
     iniset $BLAZAR_CONF_FILE DEFAULT debug $BLAZAR_DEBUG
 
-    iniset $BLAZAR_CONF_FILE manager plugins physical.host.plugin,virtual.instance.plugin
+    iniset $BLAZAR_CONF_FILE manager plugins physical.host.plugin,virtual.instance.plugin,virtual.floatingip.plugin
 
     iniset $BLAZAR_CONF_FILE api api_v2_controllers oshosts,leases
 
@@ -70,7 +57,8 @@ function configure_blazar {
     iniset $BLAZAR_CONF_FILE DEFAULT use_syslog $SYSLOG
 
     iniset_rpc_backend blazar $BLAZAR_CONF_FILE DEFAULT
-    iniupdate_rpc_backend $BLAZAR_CONF_FILE DEFAULT
+
+    setup_logging $BLAZAR_CONF_FILE
 
     ACTUAL_FILTERS=$(iniget $NOVA_CONF filter_scheduler enabled_filters)
     if [[ -z "$ACTUAL_FILTERS" ]]; then
@@ -112,23 +100,8 @@ function configure_blazar {
 function _blazar_setup_keystone {
     local conf_file=$1
     local section=$2
-    local use_auth_url=$3
 
-    if [[ -z $skip_auth_cache ]]; then
-        iniset $conf_file $section signing_dir $BLAZAR_AUTH_CACHE_DIR
-        # Create cache dir
-        create_blazar_cache_dir
-    fi
-
-    configure_auth_token_middleware $conf_file $BLAZAR_USER_NAME $BLAZAR_AUTH_CACHE_DIR $section
-}
-
-# create_blazar_cache_dir() - Part of the _blazar_setup_keystone process
-function create_blazar_cache_dir {
-    # Create cache dir
-    sudo mkdir -m 700 -p $BLAZAR_AUTH_CACHE_DIR
-    sudo chown $STACK_USER $BLAZAR_AUTH_CACHE_DIR
-    rm -f $BLAZAR_AUTH_CACHE_DIR/*
+    configure_keystone_authtoken_middleware $conf_file $BLAZAR_USER_NAME $section
 }
 
 # create_blazar_aggregate_freepool() - Create a Nova aggregate to use as freepool (for host reservation)
@@ -234,10 +207,7 @@ function clean_blazar_configuration {
 
 
 if is_service_enabled blazar blazar-m blazar-a; then
-    if [[ "$1" == "stack" && "$2" == "pre-config" ]]; then
-        echo "Pre installation steps for Blazar"
-        iniupdate_rpc_backend
-    elif [[ "$1" == "stack" && "$2" == "install" ]]; then
+    if [[ "$1" == "stack" && "$2" == "install" ]]; then
         echo_summary "Installing Blazar"
         # Use stack_install_service here to account for virtualenv
         stack_install_service blazar
